/**
 * Represents lamdaservice to invoke aws-lamdas
 */
class LambdaService {
  /**
   * @constructor
   * @param {Repository} repository
   * @param {Logger} logger
   */
  constructor({ repository, logger }) {
    this._repository = repository;
    this._logger = logger;
    this._logger.debug(`LambdaService initialized`);
  }

  /**
   * @function invokeLambdaSync
   * @description Invokes aws lamda function in synchronous way
   * @param {string} name
   * @param {json} payload
   * @return {Promise} Returns promise for lamda invokation
   */
  async invokeLambdaSync({ name, payload }) {
    try {
      this._logger.debug(`Lambda : ${name} invoked syncronously`);
      return await this._repository.invoke({name, "invokePayload" : payload});
    } catch (error) {
      this.errorHandler_(error);
    }
  }

    /**
   * @function invokeLambdaAsync
   * @description Invokes aws lamda function in asynchronous way
   * @param {string} name
   * @param {json} payload
   */
  async invokeLambdaAsync({ name, payload }) {
    try {
      this._logger.debug(`Lambda : ${name} invoked asyncronously`);

      return await this._repository.invokeAsync({name, "invokePayload" : payload});
    } catch (error) {
      this.errorHandler_(error);
    }

  }
  
  async updateLambdaConfig(config) {
    try {
      return await this._repository.updateLambdaConfig(config);
    } catch (error) {
      this.errorHandler_(error);
    }
  }
  errorHandler_(error) {
    this._logger.error("An error occurred in notification service", error);
    throw error;
  }
}

module.exports = LambdaService;
